mailr3798 - /1.3/test_suite/unit_tests/_prompt/test_state.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on November 22, 2007 - 10:41:
Author: bugman
Date: Thu Nov 22 10:41:48 2007
New Revision: 3798

URL: http://svn.gna.org/viewcvs/relax?rev=3798&view=rev
Log:
More fixes for the state.load() and state.save() arg unit tests.


Modified:
    1.3/test_suite/unit_tests/_prompt/test_state.py

Modified: 1.3/test_suite/unit_tests/_prompt/test_state.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/_prompt/test_state.py?rev=3798&r1=3797&r2=3798&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/_prompt/test_state.py (original)
+++ 1.3/test_suite/unit_tests/_prompt/test_state.py Thu Nov 22 10:41:48 2007
@@ -28,7 +28,7 @@
 from test_suite.unit_tests.state_testing_base import State_base_class
 from data_types import return_data_types
 from prompt.state import State
-from relax_errors import RelaxBinError, RelaxIntError, RelaxNoneStrError, 
RelaxStrError
+from relax_errors import RelaxBinError, RelaxIntError, RelaxNoneStrError, 
RelaxStrFileError
 
 
 # Set the variable sys.ps3 (this is required by the user functions).
@@ -61,12 +61,12 @@
 
         # Loop over the data types.
         for data in return_data_types():
-            # Catch the str arguments, and skip them.
-            if data[0] == 'str':
+            # Catch the str and file arguments, and skip them.
+            if data[0] == 'str' or data[0] == 'file':
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxStrError, self.state.load_state, 
state=data[1])
+            self.assertRaises(RelaxStrFileError, self.state.load_state, 
state=data[1])
 
 
     def test_load_argfail_dir(self):
@@ -87,12 +87,12 @@
 
         # Loop over the data types.
         for data in return_data_types():
-            # Catch the str arguments, and skip them.
-            if data[0] == 'str':
+            # Catch the str and file arguments, and skip them.
+            if data[0] == 'str' or data[0] == 'file':
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxStrError, self.state.save_state, 
state=data[1])
+            self.assertRaises(RelaxStrFileError, self.state.save_state, 
state=data[1])
 
 
     def test_save_argfail_dir(self):




Related Messages


Powered by MHonArc, Updated Thu Nov 22 11:00:18 2007